==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/frm_compose.js <==
_me = frm_compose.prototype;
function frm_compose(){};

_me.__constructor = function(oMessage) {

	var me = this;

	this.__bDisableSave = false;		
	this.__bContactsOpened = false;  //addContacts are opened
	this.__logoutOnDestruct = false; //try to logout on compose destruct
	this.__message = oMessage;

	this._title('COMPOSE::NEWMAIL');

	/*** TOP MENU ***/
	this._create('select','obj_select','header','obj_composeselect');
	this.select._fillLang({'html': "COMPOSE::HTML", 'text': "COMPOSE::TEXT"});
	this.select._onchange = function() {
		if (this._value() == 'html')
			me.body._disable(false);
		else
			me.body._disable(true);
	}

	this._create('menu','obj_hmenu','header');
	this.menu._fill([
		{"title":'COMPOSE::SEND',"arg": 'send'},
		{"title":'COMPOSE::SAVE',"arg": 'save'},
		{"title":'COMPOSE::OPTIONS',"arg": 'options'}
	]);
	
	// this line has to be presented after all elements of a window are created
	this._defaultSize();

	// SAVE (Ctrl+S) shortcut handler
	this._main.onkeydown = function(e){
		var e = e || window.event;

		if (e.ctrlKey){
			if(e.keyCode == 83 || e.keyCode == 13){
				if (e.preventDefault)
					e.preventDefault();
				else
				if (e.cancelBubble)
					e.cancelBubble = true;

				if (e.keyCode == 83)
					me.__save();
				else
					me.__send(false, false);

				return false;
			}
		}
		else
		if (e.keyCode == 27 && me._onclose && me._onclose())
			me._destruct();

		return true;
	};

	this.menu._onclick = function(e,elm,id,arg){
		switch(arg){
		case 'send':
			me.__send(false, false);
			break;
		case 'save':
			if (!me.__bDisableSave && me.__changed())
				me.__send(true, true);
			break;
		case 'options':
			if (me.frmsettings && !me.frmsettings._destructed)
				me.frmsettings._focus();
			else
				me.frmsettings = gui._create('mail_settings', 'frm_mail_settings', '', '', me._aSettings, true, [me, '__onSettings']);
			break;
		}
	}

	this._draw('frm_compose','main',{disable_ab:sPrimaryAccountGW<1});

	this.body._onkeydown = function(e){
		switch(e.keyCode){
		case 13:
			if (!e.ctrlKey) return true;
			me.__send(false, false);
			return false;
		case 83:
			if (!e.ctrlKey) return true;
			me.__save();
			return false;
		case 27:
			if (me._onclose && me._onclose()) me._destruct();
		}
	};

	this.body.__getSpellLang = function(){
		return me._aSettings.VALUES.spellchecker || GWOthers.getItem('MAIL_SETTINGS_DEFAULT','spellchecker');
	};
	//iframe focus
	this.body.__doc.onmousedown = function(){
		me._focus();
	};

	// Load mail settings
	storage.library('gw_others');
	this._aSettings = GWOthers.get('MAIL_SETTINGS_DEFAULT','storage');
	this._aMailSettingsGeneral = GWOthers.get('MAIL_SETTINGS_GENERAL','storage');

	/******************/

	if (sPrimaryAccountGW>0){
		function btn(e) {
			if (me.__bContactsOpened)
				return;

			var id = this.id.substr(me._pathName.length);
			var aTabsNames = {'to': "DATAGRID_ITEMS_VIEW::TO", 'cc': "DATAGRID_ITEMS_VIEW::CC", 'bcc': "DATAGRID_ITEMS_VIEW::BCC"};
			var aTabsValues = {'to': me.to._value(), 'cc': me.cc._value(), 'bcc': me.bcc._value()};

			switch(id) {
				case 'btn_to': gui._create('add_address', 'frm_addaddress', '', '', [me, '__onPopupClose'], aTabsNames, aTabsValues, 'to', true); me.__bContactsOpened = true; break;
				case 'btn_cc': gui._create('add_address', 'frm_addaddress', '', '', [me, '__onPopupClose'], aTabsNames, aTabsValues, 'cc', true); me.__bContactsOpened = true; break;
				case 'btn_bcc': gui._create('add_address', 'frm_addaddress', '', '', [me, '__onPopupClose'], aTabsNames, aTabsValues, 'bcc', true); me.__bContactsOpened = true; break;
			}
		}

		this._getAnchor('btn_to').onclick = btn;
		this._getAnchor('btn_cc').onclick = btn;
		this._getAnchor('btn_bcc').onclick = btn;
	}

	/******************/

	this.select._value(this.__message.isHtml() ? 'html' : 'text');

	// Fill controls with arg
	this.to._value(this.__message.sTo);
	this.to.__eIN.tabIndex = 1;
	this.cc._value(this.__message.sCc);
	this.cc.__eIN.tabIndex = 2;
	this.bcc._value(this.__message.sBcc);
	this.bcc.__eIN.tabIndex = 3;
	this.subject._value(this.__message.sSubject);
	this.subject.__eIN.tabIndex = 4;

	//Copy subject into window title
	this.subject._onkeyup = function(){
		var sTitle = this._value();
		if (sTitle){
			if (sTitle.length>32)
				sTitle = sTitle.substr(0,32)+'...';

			me._title(sTitle,true);
		}
		else
			me._title('COMPOSE::NEWMAIL');
	};
	this.subject._onkeyup();
	
	//Meanwhile FOCUS solution
	this.ecatch.__eIN.tabIndex = 5;
	this.ecatch._onfocus = function(){
		me.body._focus(true);
	};


	this.body._value(this.__message.sBody);
	this.attach._value(this.__message.aAttachments);

	this.attach._onuploadstart = function(){
		me.menu._fill([
			{"title":'COMPOSE::SEND',"arg": 'send',disabled:true},
			{"title":'COMPOSE::SAVE',"arg": 'save',disabled:true},
			{"title":'COMPOSE::OPTIONS',"arg": 'options'}
			]);
	};

	this.attach._onuploadend = function(){
		me.menu._fill([
			{"title":'COMPOSE::SEND',"arg": 'send'},
			{"title":'COMPOSE::SAVE',"arg": 'save'},
			{"title":'COMPOSE::OPTIONS',"arg": 'options'}
			]);
	};

	this._onclose = function() {

		if (!me.__bDisableSave && me.__changed()) {
			//bring frm to front
			me._focus();
			//call save confirmation
			var cnf = gui._create('frm_confirm','frm_confirm_threestates', '','', [me, '__confirmed'], 'CONFIRMATION::SAVE_TITLE','CONFIRMATION::SAVE_CONFIRMATION', '','CONFIRMATION::SAVE','CONFIRMATION::DONTSAVE');
				cnf.btn_cancel2._onclick = function() {
					me.__logoutOnDestruct = false;
					this._parent._destruct();
				}

			return false;
		}
		else
			return true;
	};

	this._bAutoSave = parseInt(this._aMailSettingsGeneral['VALUES']['autosave']);
	this._nAutoSaveInterval = parseInt(this._aMailSettingsGeneral['VALUES']['autosave_minutes'])*60000;

	if (this._bAutoSave && this._nAutoSaveInterval)
		setTimeout('try{'+this._pathName+'.__autoSave()}catch(e){}',this._nAutoSaveInterval);

	this._add_destructor('__onDestruct');

	this.__rememberState();

	if (oMessage && oMessage.sTo)
		this.body._focus();
	else
		this.to._focus();
};

_me.__onDestruct = function() {
	this.__message.dispose();
};

_me.__autoSave = function() {
	if (this._destructed)
	return;

	if (!this.__bDisableSave && this.__changed())
		this.__save();

	setTimeout('try{'+this._pathName+'.__autoSave();}catch(e){}',this._nAutoSaveInterval);
};

_me.__onSettings = function(aValues) {
	this._aSettings['VALUES'] = aValues;
};

_me.__rememberState = function() {
	this.__sSavedTo = this.to._value();
	this.__sSavedCc = this.cc._value();
	this.__sSavedBcc = this.bcc._value();
	this.__sSavedSubject = this.subject._value();
	// TODO remember attachements
	this.__sSavedBody = this.body._value();
};

_me.__changed = function() {
	// TODO compare state of attachments
	return this.__sSavedTo != this.to._value() || this.__sSavedCc != this.cc._value() || this.__sSavedBcc != this.bcc._value() || this.__sSavedSubject != this.subject._value() || this.__sSavedBody != this.body._value();
};

_me.__confirmed = function(bSave) {
	if (bSave)
		this.__send(true, false);

	this.__bDisableSave = true;
	this._destruct();

	//we need to call confirms in all opened compose windows before logout
	if (this.__logoutOnDestruct && gui.frm_main)
		gui.frm_main.__logout();
};

_me.__send = function(bSave, bKeepAttachments) {
	this.__bDisableSave = true;

	this.__message.sTo = this.to._value();
	this.__message.sCc = this.cc._value();
	this.__message.sBcc = this.bcc._value();
	this.__message.sSubject = this.subject._value();
	this.__message.aAttachments = this.attach._value();
	this.__message.sBody = this.body._value();
	
	var bHtml = (this.select._value() == 'html') ? true : false;
	this.__message.setHtml(bHtml);

	if (bSave) {
		if (!this.__message.save(bKeepAttachments, [this, '__messageSaved'])) {
			this.__bDisableSave = false;
			alert(getLang('ALERTS::MESSAGE_NOT_SAVED'));
		}
	}
	else {
		if (this.__message.send(bKeepAttachments, [this, '__messageSent'], this._aSettings['VALUES'])) {
			this.__oldZIndex = this.__eContainer.style.zIndex;
			this.__eContainer.style.zIndex = -1000;
		}
		else
			this.__bDisableSave = false;
	}

};

_me.__save_recipients = function(){

	var rcp = (this.__message.sTo || '') + (this.__message.sCc || '') + (this.__message.sBcc || '');

	if (!this.__bDisableSave || !rcp) return;

	//clean duplicity
	function clean(emails){
		for(var i = emails.length-1;i>=0;i--){
			if (emails[i].email){
				for(j = i-1;j>=0;j--){
					if (emails[j].email && emails[i].email.toLowerCase() == emails[j].email.toLowerCase()){
					    emails.splice(i,1);
					    break;
					}
				}
			}
			else
				emails.splice(i,1);
		}

		return emails;
	};

	var emails = clean(MailAddress.splitEmailsAndNames(rcp).reverse());

	if ((rcp = dataSet.get('suggest_address'))){
		var emails2 = MailAddress.splitEmailsAndNames(rcp);

		emails = emails.concat(emails2);
		emails = clean(emails);
	}

	emails = emails.slice(0,10);

	var out = '';
	for(var i=0;i<emails.length;i++)
		out += (out?';':'')+MailAddress.createEmail(emails[i].name,emails[i].email);

	dataSet.add('suggest_address','',out);
};

_me.__messageSaved = function(bOK, bFirstTime) {

	/*
	stejne se nic nestane protoze email je precteny
	if (bOK && bFirstTime){
		folders.list({'aid':sPrimaryAccount},'folders');
	}
	*/

	if (this._destructed)
		return;

	if (bOK)
		this.__rememberState();
	else
		alert(getLang('ALERTS::MESSAGE_NOT_SAVED'));

	this.__bDisableSave = false;
};

_me.__messageSent = function(bOK, sUID, sError)
{
	if (this._destructed)
		return;

    this.__save_recipients();
	
	if (bOK)
		this._destruct();
	else {
		var sErrOut = '';

		this.__eContainer.style.zIndex = this.__oldZIndex;
		this.__bDisableSave = false;
		switch (sUID) {
			case 'SMTP_from_failed':
			case 'SMTP_recipients_failed':
				sErrOut = getLang('ALERTS::MESSAGE_NOT_SENT') + '\r\n' + getLang('ALERTS::'+sUID.toUpperCase());
				break;

			case 'SMTP_data_not_accepted':
				sErrOut = getLang('ALERTS::MESSAGE_NOT_SENT') + '\r\n' + getLang('ALERTS::'+sUID.toUpperCase());
				break;

			default:
				sErrOut = getLang('ALERTS::MESSAGE_NOT_SENT');
		}

		if (sError) sErrOut += "\r\n\r\n"+ sError.unentityify();
		alert(sErrOut);
	}
};

_me.__onPopupClose = function(bOK, aAddresses)
{
	if (bOK){
		this.to._value(aAddresses['to'].join(', '));
		this.cc._value(aAddresses['cc'].join(', '));
		this.bcc._value(aAddresses['bcc'].join(', '));
	}
	this.__bContactsOpened = false;
};

_me.__save = function() {
	if (this._destructed)
		return false;

	this.__send(true, true);
	return true;
};

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/frm_compose.js <==
_me = frm_compose.prototype;
function frm_compose(){};

_me.__constructor = function(oMessage) {

	var me = this;

	this.__bDisableSave = false;		
	this.__bContactsOpened = false;  //addContacts are opened
	this.__logoutOnDestruct = false; //try to logout on compose destruct
	this.__message = oMessage;

	this._title('COMPOSE::NEWMAIL');

	/*** TOP MENU ***/
	this._create('select','obj_select','header','obj_composeselect');
	this.select._fillLang({'html': "COMPOSE::HTML", 'text': "COMPOSE::TEXT"});
	this.select._onchange = function() {
		if (this._value() == 'html')
			me.body._disable(false);
		else
			me.body._disable(true);
	};

	this._create('menu','obj_hmenu','header');
	this.menu._fill([
		{"title":'COMPOSE::SEND',"arg": 'send'},
		{"title":'COMPOSE::SAVE',"arg": 'save'},
		{"title":'COMPOSE::OPTIONS',"arg": 'options'}
	]);
	
	// this line has to be presented after all elements of a window are created
	this._defaultSize();

	// SAVE (Ctrl+S) shortcut handler
	this._main.onkeydown = function(e){
		var e = e || window.event;

		if (e.ctrlKey){
			if(e.keyCode == 83 || e.keyCode == 13){
				if (e.preventDefault)
					e.preventDefault();
				else
				if (e.cancelBubble)
					e.cancelBubble = true;

				if (e.keyCode == 83)
					me.__save();
				else
					me.__send(false, false);

				return false;
			}
		}
		else
		if (e.keyCode == 27 && me._onclose && me._onclose())
			me._destruct();

		return true;
	};

	this.menu._onclick = function(e,elm,id,arg){
		switch(arg){
		case 'send':
			me.__send(false, false);
			break;
		case 'save':
			if (!me.__bDisableSave && me.__changed())
				me.__send(true, true);
			break;
		case 'options':
			if (me.frmsettings && !me.frmsettings._destructed)
				me.frmsettings._focus();
			else
				me.frmsettings = gui._create('mail_settings', 'frm_mail_settings', '', '', me._aSettings, true, [me, '__onSettings']);
			break;
		}
	}

	this._draw('frm_compose','main',{disable_ab:sPrimaryAccountGW<1});

	this.body._onkeydown = function(e){
		switch(e.keyCode){
		case 13:
			if (!e.ctrlKey) return true;
			me.__send(false, false);
			return false;
		case 83:
			if (!e.ctrlKey) return true;
			me.__save();
			return false;
		case 27:
			if (me._onclose && me._onclose()) me._destruct();
		}
	};

	this.body.__getSpellLang = function(){
		return me._aSettings.VALUES.spellchecker || GWOthers.getItem('MAIL_SETTINGS_DEFAULT','spellchecker');
	};
	//iframe focus
	this.body.__doc.onmousedown = function(){
		me._focus();
	};

	// Load mail settings
	storage.library('gw_others');
	this._aSettings = GWOthers.get('MAIL_SETTINGS_DEFAULT','storage');
    this._aSettings.from = getPrimaryAccountFromAddress();
    
	this._aMailSettingsGeneral = GWOthers.get('MAIL_SETTINGS_GENERAL','storage');
	/******************/

	if (sPrimaryAccountGW>0){
		function btn(e) {
			if (me.__bContactsOpened)
				return;

			var id = this.id.substr(me._pathName.length);
			var aTabsNames = {'to': "DATAGRID_ITEMS_VIEW::TO", 'cc': "DATAGRID_ITEMS_VIEW::CC", 'bcc': "DATAGRID_ITEMS_VIEW::BCC"};
			var aTabsValues = {'to': me.to._value(), 'cc': me.cc._value(), 'bcc': me.bcc._value()};

			switch(id) {
				case 'btn_to': gui._create('add_address', 'frm_addaddress', '', '', [me, '__onPopupClose'], aTabsNames, aTabsValues, 'to', true); me.__bContactsOpened = true; break;
				case 'btn_cc': gui._create('add_address', 'frm_addaddress', '', '', [me, '__onPopupClose'], aTabsNames, aTabsValues, 'cc', true); me.__bContactsOpened = true; break;
				case 'btn_bcc': gui._create('add_address', 'frm_addaddress', '', '', [me, '__onPopupClose'], aTabsNames, aTabsValues, 'bcc', true); me.__bContactsOpened = true; break;
			}
		}

		this._getAnchor('btn_to').onclick = btn;
		this._getAnchor('btn_cc').onclick = btn;
		this._getAnchor('btn_bcc').onclick = btn;
	}

	/******************/

	this.select._value(this.__message.isHtml() ? 'html' : 'text');

	// Fill controls with arg
	this.to._value(this.__message.sTo);
	this.to.__eIN.tabIndex = 1;
	this.cc._value(this.__message.sCc);
	this.cc.__eIN.tabIndex = 2;
	this.bcc._value(this.__message.sBcc);
	this.bcc.__eIN.tabIndex = 3;
	this.subject._value(this.__message.sSubject);
	this.subject.__eIN.tabIndex = 4;

	//Copy subject into window title
	this.subject._onkeyup = function(){
		var sTitle = this._value();
		if (sTitle){
			if (sTitle.length>32)
				sTitle = sTitle.substr(0,32)+'...';

			me._title(sTitle,true);
		}
		else
			me._title('COMPOSE::NEWMAIL');
	};
	this.subject._onkeyup();
	
	//Meanwhile FOCUS solution
	this.ecatch.__eIN.tabIndex = 5;
	this.ecatch._onfocus = function(){
		me.body._focus(true);
	};


	this.body._value(this.__message.sBody);
	this.attach._value(this.__message.aAttachments);

	this.attach._onuploadstart = function(){
		me.menu._fill([
			{"title":'COMPOSE::SEND',"arg": 'send',disabled:true},
			{"title":'COMPOSE::SAVE',"arg": 'save',disabled:true},
			{"title":'COMPOSE::OPTIONS',"arg": 'options'}
			]);
	};

	this.attach._onuploadend = function(){
		me.menu._fill([
			{"title":'COMPOSE::SEND',"arg": 'send'},
			{"title":'COMPOSE::SAVE',"arg": 'save'},
			{"title":'COMPOSE::OPTIONS',"arg": 'options'}
			]);
	};

	this._onclose = function() {

		if (!me.__bDisableSave && me.__changed()) {
			//bring frm to front
			me._focus();
			//call save confirmation
			if (!dataSet.get('main',['sid'])){
				try{
				var cnf = gui._create('frm_confirm','frm_confirm', '','', [me, '__confirmed'], 'CONFIRMATION::EXPIRED','CONFIRMATION::EXPIRED_MSG');
				}
				catch(r){
				inspect(r);

				}
			}
			else{
				var cnf = gui._create('frm_confirm','frm_confirm_threestates', '','', [me, '__confirmed'], 'CONFIRMATION::SAVE_TITLE','CONFIRMATION::SAVE_CONFIRMATION', '','CONFIRMATION::SAVE','CONFIRMATION::DONTSAVE');
					cnf.btn_cancel2._onclick = function() {
						//me.__logoutOnDestruct = false;
						this._parent._destruct();
					};
			}

			return false;
		}
		else
			return true;
	};

	this._bAutoSave = parseInt(this._aMailSettingsGeneral['VALUES']['autosave']);
	this._nAutoSaveInterval = parseInt(this._aMailSettingsGeneral['VALUES']['autosave_minutes'])*60000;

	if (this._bAutoSave && this._nAutoSaveInterval)
		setTimeout('try{'+this._pathName+'.__autoSave()}catch(e){}',this._nAutoSaveInterval);

	this._add_destructor('__onDestruct');

	this.__rememberState();

	if (oMessage && oMessage.sTo)
		this.body._focus();
	else
		this.to._focus();
};

_me.__onDestruct = function() {
	this.__message.dispose();
};

_me.__autoSave = function() {
	if (this._destructed)
	return;

	if (!this.__bDisableSave && this.__changed())
		this.__save();

	setTimeout('try{'+this._pathName+'.__autoSave();}catch(e){}',this._nAutoSaveInterval);
};

_me.__onSettings = function(aValues) {
	this._aSettings['VALUES'] = aValues;
};

_me.__rememberState = function() {
	this.__sSavedTo = this.to._value();
	this.__sSavedCc = this.cc._value();
	this.__sSavedBcc = this.bcc._value();
	this.__sSavedSubject = this.subject._value();

    this.__sSavedAtt = [];
	if (this.__message.aAttachments){
		var tmp = this.__message.aAttachments.attachments;
		for (var i in tmp)
            this.__sSavedAtt.push(tmp[i].values);
	}

	this.__sSavedBody = this.body._value();
};

_me.__changed = function() {
	var att = this.attach._value();
	if (att && (att = att.attachments) && !arrayCompare(att,this.__sSavedAtt))
		return true;

	return this.__sSavedTo != this.to._value() || this.__sSavedCc != this.cc._value() || this.__sSavedBcc != this.bcc._value() || this.__sSavedSubject != this.subject._value() || this.__sSavedBody != this.body._value();
};

_me.__confirmed = function(bSave) {
	if (bSave)
		this.__send(true, false);

	this.__bDisableSave = true;
	this._destruct();

	//we need to call confirms in all opened compose windows before logout
	if (this.__logoutOnDestruct && gui.frm_main)
		gui.frm_main.__logout();
};

_me.__send = function(bSave, bKeepAttachments) {

	this.__bDisableSave = false;

	this.__message.sTo = this.to._value();
	this.__message.sCc = this.cc._value();
	this.__message.sBcc = this.bcc._value();
	this.__message.sSubject = this.subject._value();
	this.__message.aAttachments = this.attach._value();
	this.__message.sBody = this.body._value();
	
	var bHtml = (this.select._value() == 'html') ? true : false;

	this.__message.setHtml(bHtml);

	if (bSave) {
		if (!this.__message.save(bKeepAttachments, [this, '__messageSaved'])) {
		//	this.__bDisableSave = false;
			alert(getLang('ALERTS::MESSAGE_NOT_SAVED'));
		}
		else
			this.__bDisableSave = true;
	}
	else {
		if (this.__message.send(bKeepAttachments, [this, '__messageSent'], this._aSettings['VALUES']))
            this.__hide();
	}

};

_me.__save_recipients = function(){

	var rcp = (this.__message.sTo || '') +';'+ (this.__message.sCc || '') +';'+ (this.__message.sBcc || '');

	if (!rcp) return;   //!this.__bDisableSave ||

	//clean duplicity
	function clean(emails){
		for(var i = emails.length-1;i>=0;i--){
			if (emails[i].email){
				for(j = i-1;j>=0;j--){
					if (emails[j].email && emails[i].email.toLowerCase() == emails[j].email.toLowerCase()){
					    emails.splice(i,1);
					    break;
					}
				}
			}
			else
				emails.splice(i,1);
		}

		return emails;
	};

	var emails = clean(MailAddress.splitEmailsAndNames(rcp).reverse());

	if ((rcp = dataSet.get('suggest_address'))){
		var emails2 = MailAddress.splitEmailsAndNames(rcp);

		emails = emails.concat(emails2);
		emails = clean(emails);
	}

	emails = emails.slice(0,10);

	var out = '';
	for(var i=0;i<emails.length;i++)
		out += (out.length>0?';':'')+(emails[i].email.indexOf('[')==0?emails[i].email:MailAddress.createEmail(emails[i].name,emails[i].email));

	dataSet.add('suggest_address','',out);
};

_me.__messageSaved = function(bOK, bFirstTime) {

	/*
	stejne se nic nestane protoze email je precteny
	if (bOK && bFirstTime){
		folders.list({'aid':sPrimaryAccount},'folders');
	}
	*/

	if (this._destructed)
		return;

	if (bOK)
		this.__rememberState();
	else
		alert(getLang('ALERTS::MESSAGE_NOT_SAVED'));

	this.__bDisableSave = false;
};

_me.__messageSent = function(bOK, sUID, sError)
{
	if (this._destructed)
		return;

    this.__save_recipients();
	
	if (bOK){
        this.__bDisableSave = true;
		this._destruct();
	}
	else {
		var sErrOut = '';

		this.__show();
		
		this.__bDisableSave = false;
		switch (sUID) {
			case 'SMTP_from_failed':
			case 'SMTP_recipients_failed':
				sErrOut = getLang('ALERTS::MESSAGE_NOT_SENT') + '\n\n' + getLang('ALERTS::'+sUID.toUpperCase());
				break;

			case 'SMTP_data_not_accepted':
				sErrOut = getLang('ALERTS::MESSAGE_NOT_SENT') + '\n\n' + getLang('ALERTS::'+sUID.toUpperCase());
				break;

			default:
				sErrOut = getLang('ALERTS::MESSAGE_NOT_SENT')+'\n';
		}

		if (sError) sErrOut += "\n"+ sError.unentityify();
		alert(sErrOut);
	}
};

_me.__onPopupClose = function(bOK, aAddresses)
{
	if (bOK){
		this.to._value(aAddresses['to'].join(', '));
		this.cc._value(aAddresses['cc'].join(', '));
		this.bcc._value(aAddresses['bcc'].join(', '));
	}
	this.__bContactsOpened = false;
};

_me.__save = function() {
	if (this._destructed)
		return false;

	this.__send(true, true);
	return true;
};
